Exception: Spikard::Errors::ConflictError
- Defined in:
- lib/spikard/errors.rb
Instance Attribute Summary
Attributes inherited from Error
#problem_details_type, #status_code
Instance Method Summary collapse
-
#initialize(message = nil) ⇒ ConflictError
constructor
Raised when the request conflicts with the current state of the resource.
Methods inherited from Error
Constructor Details
#initialize(message = nil) ⇒ ConflictError
Raised when the request conflicts with the current state of the resource.
61 62 63 |
# File 'lib/spikard/errors.rb', line 61 def initialize( = nil) super(, status_code: 409, problem_details_type: nil) end |