Exception: Spikard::Errors::RateLimitedError
- Defined in:
- lib/spikard/errors.rb
Instance Attribute Summary
Attributes inherited from Error
#problem_details_type, #status_code
Instance Method Summary collapse
-
#initialize(message = nil) ⇒ RateLimitedError
constructor
Raised when the client exceeds the configured request rate limit.
Methods inherited from Error
Constructor Details
#initialize(message = nil) ⇒ RateLimitedError
Raised when the client exceeds the configured request rate limit.
54 55 56 |
# File 'lib/spikard/errors.rb', line 54 def initialize( = nil) super(, status_code: 429, problem_details_type: nil) end |